summaryrefslogtreecommitdiff
path: root/src/broadcom
diff options
context:
space:
mode:
authorIago Toral Quiroga <itoral@igalia.com>2023-10-16 10:52:01 +0200
committerMarge Bot <emma+marge@anholt.net>2023-10-25 19:11:37 +0000
commit84001ea425811cdb07c94e294f51263d9a36b778 (patch)
tree154ec8183cbef506bbe9e4e2ef2bfa772ba9011f /src/broadcom
parentd0f775e54de81a8febb0ee67a343b3827514d895 (diff)
downloadmesa-84001ea425811cdb07c94e294f51263d9a36b778.tar.gz
mesa-84001ea425811cdb07c94e294f51263d9a36b778.tar.bz2
mesa-84001ea425811cdb07c94e294f51263d9a36b778.zip
v3dv: fix confusing nomenclature about DRM nodes
We have been using drm_render_device to refer to the render device and drm_primary_device to refer to the display device, but that is confusing because the render device also has a primary node (for legacy reasons), so don't use primary to refer to the display device. Reviewed-by: Alejandro PiƱeiro <apinheiro@igalia.com> Acked-by: Erico Nunes <nunes.erico@gmail.com> Part-of: <https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/25748>
Diffstat (limited to 'src/broadcom')
-rw-r--r--src/broadcom/vulkan/v3dv_device.c33
1 files changed, 16 insertions, 17 deletions
diff --git a/src/broadcom/vulkan/v3dv_device.c b/src/broadcom/vulkan/v3dv_device.c
index f8adb03b3c3..48aa967e56f 100644
--- a/src/broadcom/vulkan/v3dv_device.c
+++ b/src/broadcom/vulkan/v3dv_device.c
@@ -995,8 +995,8 @@ v3dv_physical_device_init_disk_cache(struct v3dv_physical_device *device)
static VkResult
create_physical_device(struct v3dv_instance *instance,
- drmDevicePtr drm_render_device,
- drmDevicePtr drm_primary_device)
+ drmDevicePtr gpu_device,
+ drmDevicePtr display_device)
{
VkResult result = VK_SUCCESS;
int32_t master_fd = -1;
@@ -1021,8 +1021,8 @@ create_physical_device(struct v3dv_instance *instance,
if (result != VK_SUCCESS)
goto fail;
- assert(drm_render_device);
- const char *path = drm_render_device->nodes[DRM_NODE_RENDER];
+ assert(gpu_device);
+ const char *path = gpu_device->nodes[DRM_NODE_RENDER];
render_fd = open(path, O_RDWR | O_CLOEXEC);
if (render_fd < 0) {
fprintf(stderr, "Opening %s failed: %s\n", path, strerror(errno));
@@ -1037,12 +1037,12 @@ create_physical_device(struct v3dv_instance *instance,
const char *primary_path;
#if !using_v3d_simulator
- if (drm_primary_device)
- primary_path = drm_primary_device->nodes[DRM_NODE_PRIMARY];
+ if (display_device)
+ primary_path = display_device->nodes[DRM_NODE_PRIMARY];
else
primary_path = NULL;
#else
- primary_path = drm_render_device->nodes[DRM_NODE_PRIMARY];
+ primary_path = gpu_device->nodes[DRM_NODE_PRIMARY];
#endif
struct stat primary_stat = {0}, render_stat = {0};
@@ -1069,14 +1069,14 @@ create_physical_device(struct v3dv_instance *instance,
device->render_devid = render_stat.st_rdev;
#if using_v3d_simulator
- device->device_id = drm_render_device->deviceinfo.pci->device_id;
+ device->device_id = gpu_device->deviceinfo.pci->device_id;
#endif
if (instance->vk.enabled_extensions.KHR_display ||
instance->vk.enabled_extensions.EXT_acquire_drm_display) {
#if !using_v3d_simulator
/* Open the primary node on the vc4 display device */
- assert(drm_primary_device);
+ assert(display_device);
master_fd = open(primary_path, O_RDWR | O_CLOEXEC);
#else
/* There is only one device with primary and render nodes.
@@ -1240,14 +1240,13 @@ enumerate_devices(struct vk_instance *vk_instance)
break;
}
#else
/* On actual hardware, we should have a render node (v3d)
* and a primary node (vc4). We will need to use the primary
* to allocate WSI buffers and share them with the render node
* via prime, but that is a privileged operation so we need the
* primary node to be authenticated, and for that we need the
* display server to provide the device fd (with DRI3), so we
* here we only check that the device is present but we don't
* try to open it.
*/
if (devices[i]->bustype != DRM_BUS_PLATFORM)
continue;
@@ -1240,14 +1240,13 @@ enumerate_devices(struct vk_instance *vk_instance)
}
#else
- /* On actual hardware, we should have a render node (v3d)
- * and a primary node (vc4). We will need to use the primary
- * to allocate WSI buffers and share them with the render node
- * via prime, but that is a privileged operation so we need the
- * primary node to be authenticated, and for that we need the
- * display server to provide the device fd (with DRI3), so we
- * here we only check that the device is present but we don't
- * try to open it.
+ /* On actual hardware, we should have a gpu device (v3d) and a display
+ * device (vc4). We will need to use the display device to allocate WSI
+ * buffers and share them with the render node via prime, but that is a
+ * privileged operation so we need t have an authenticated display fd
+ * and for that we need the display server to provide the it (with DRI3),
+ * so here we only check that the device is present but we don't try to
+ * open it.
*/
if (devices[i]->bustype != DRM_BUS_PLATFORM)